/*
* Copyright (C) 2001 NetLabs SRL (ejbs@netlabs.com.uy)
*
* This file is part of wccpd.
*
* wccpd is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* wccpd is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with wccpd; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/**
* Defines utility functions used by other modules.
*/

#ifndef __UTIL_H__
#define __UTIL_H__

#include "types.h"


#define STR(s)	#s
/**
* Stringifies a preprocessor define.
*
* Makes a string from a preprocessor define.
* Usage:
*     cc -DBASEDIR=/usr source.C
*
*     ------- source.C ----------
*     #include "util.h"
*
*     char* str = XSTR (BASEDIR);
*     ------- end source.C ------
*
* @param s is the name of the preprocessor define.
*/
#define XSTR(s) STR(s)

/**
* Maximum number of arguments to executeCmd, not including neither the
* command name nor the trailing NULL.
*/
#define MAX_CMDEXEC_ARGS	32

/**
* Gets the string representation of a given IP address.
*
* This function uses a statically allocated buffer, thus each call overwrites
* the previous call's result.
*
* @param ip the IP address to convert, in Network Byte Order.
* @return the quad-dot notation string of the given ip.
*/
extern char* ip2str (u_int32 ip);

/**
* Executes a system command with the given parameters.
*
* This function is just a wrapper arround fork/execv that forks and executes
* the given command.  The full path to the command is <libexecdir>/wccpd/cmd. 
* It will wait for the command to complete before it returns.
*
* The variable length char* parameter list must be NULL terminated, and must
* not exceed MAX_CMDEXEC_ARGS parameters (not including neither the command
* name nor the trailing NULL).
*
* @param cmd the command to execute.
*/
extern void executeCmd (char* cmd, ...);

/**
* Make the current process a daemon.
*
* Forks off and closes all files.
*
* @return 0 on the daemon, pid on the parent (which exists) and -1 on error.
*/
extern pid_t daemonize ();

/**
* Catches SIGTERM and SIGINT.
*
* Each time one of the signals is received, the integer pointed to by fShutdown
* is incremented.
*
* @param fShutdown a pointer to an integer to be incremented.
*/
extern void setSignals (int* fShutdown);

#endif /* __UTIL_H__ */
